/***************************************************************************//**
 * @file
 * @brief
 *******************************************************************************
 * # License
 * <b>Copyright 2023 Silicon Laboratories Inc. www.silabs.com</b>
 *******************************************************************************
 *
 * SPDX-License-Identifier: Zlib
 *
 * The licensor of this software is Silicon Laboratories Inc.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty. In no event will the authors be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 *
 ******************************************************************************/
#ifndef __SL_WISUN_CONFIG_H__
#define __SL_WISUN_CONFIG_H__

#include "sl_component_catalog.h"

#ifdef __cplusplus
extern "C" {
#endif

#if defined(SL_CATALOG_WISUN_STACK_PRESENT) ||   \
    defined(SL_CATALOG_WISUN_LFN_DEVICE_SUPPORT_PRESENT)

#include <stddef.h>
#include <stdint.h>
#include "sl_wisun_types.h"
{% if config.deviceType is not none %}

//! Wi-SUN device type
#if !defined(WISUN_CONFIG_DEVICE_TYPE)
#define WISUN_CONFIG_DEVICE_TYPE                {{config.deviceType}}
#endif
{%- endif -%}

{% if config.deviceProfile is not none %}

//! Wi-SUN device profile (LFN)
#if !defined(WISUN_CONFIG_DEVICE_PROFILE)
#define WISUN_CONFIG_DEVICE_PROFILE             {{config.deviceProfile}}
#endif
{%- endif -%}
{% if config.networkName is not none %}

//! Wi-SUN network name
#define WISUN_CONFIG_NETWORK_NAME               "{{config.networkName}}"
{%- endif -%}
{% if config.networkSize is not none %}

//! Wi-SUN network size
#define WISUN_CONFIG_NETWORK_SIZE               {{config.networkSize}}
{%- endif -%}
{% if config.txOutputPower is not none %}

//! Wi-SUN TX output power
#define WISUN_CONFIG_TX_POWER                   {{config.txOutputPower}}
{%- endif -%}
{% if config.dwellInterval is not none %}

//! Wi-SUN DWELL Interval (15-255) default 255
#define WISUN_CONFIG_DWELL_INTERVAL             {{config.dwellInterval}}U
{%- endif -%}
{% if config.allowedChannels is not none %}

//! Wi-SUN allowed channels
#define WISUN_CONFIG_ALLOWED_CHANNELS           "{{config.allowedChannelsStr}}"
extern const sl_wisun_channel_mask_t wisun_config_allowed_channels_mask;
{%- endif -%}
{% if config.defaultPhy is not none %}

{% if config.defaultPhy['profile'] == 'wisun_fan_1_0' -%}
//! Wi-SUN default PHY - FAN1.0 profile
#define WISUN_CONFIG_DEFAULT_PHY_FAN10

//! Wi-SUN default PHY - Regulatory Domain
#define WISUN_CONFIG_REGULATORY_DOMAIN          {{config.defaultPhy['regulatoryDomain']}}

//! Wi-SUN default PHY - Operating Class
#define WISUN_CONFIG_OPERATING_CLASS            {{config.defaultPhy['operatingClass']}}

//! Wi-SUN default PHY - Operating Mode
#define WISUN_CONFIG_OPERATING_MODE             {{config.defaultPhy['operatingMode']}}
{%- else -%}
//! Wi-SUN default PHY - FAN1.1 profile
#define WISUN_CONFIG_DEFAULT_PHY_FAN11

//! Wi-SUN default PHY - Regulatory domain
#define WISUN_CONFIG_REGULATORY_DOMAIN          {{config.defaultPhy['regulatoryDomain']}}

//! Wi-SUN default PHY - Channel Plan ID
#define WISUN_CONFIG_CHANNEL_PLAN_ID            {{config.defaultPhy['channelPlanId']}}

//! Wi-SUN default PHY - PHY Mode ID
#define WISUN_CONFIG_PHY_MODE_ID                {{config.defaultPhy['phyModeId']}}
{%- endif %}

{%- endif %}
{% if config.broadcastRetries is not none %}
//! Wi-SUN Broadcast retries
#define WISUN_CONFIG_BROADCAST_RETRIES          {{config.broadcastRetries}}
{%- endif -%}
{% if config.modeSwitchPhys is not none %}
{% if config.modeSwitchPhys|length > 0 %}
//! Wi-SUN Mode Switch PHYs
#define WISUN_CONFIG_MODE_SWITCH_PHYS           { {{ config.modeSwitchPhyModeIds|join(', ') }} }

//! Wi-SUN Mode Switch PHYs number
#define WISUN_CONFIG_MODE_SWITCH_PHYS_NUMBER    {{config.modeSwitchPhys|length}}

//! Wi-SUN Mode Switch PHYs
extern const uint8_t wisun_config_ms_phys[];
{%- endif -%}
{%- endif -%}
{% if config.macList is not none %}
{% if config.macList|length > 0 %}

//! Wi-SUN MAC list struct for allowed and denied mac addresses
typedef struct {
  const uint8_t mac_list_num;
  const sl_wisun_mac_address_t mac_list[];
} wisun_config_mac_list_t;
{%- endif -%}
{%- endif -%}
{% if config.macAddress is not none %}

#define WISUN_CONFIG_MAC_ADDRESS_PRESENT
//! Wi-SUN MAC address
extern const sl_wisun_mac_address_t wisun_config_mac_address;
{%- endif -%}
{% if config.macList is not none %}
{% if (config.macList|length > 0) and (config.isDenyList is sameas false) %}

#define WISUN_CONFIG_MAC_ALLOW_LIST_PRESENT 
//! Wi-SUN MAC allow list
extern const wisun_config_mac_list_t wisun_config_mac_allow_list;
{%- endif -%}
{% if (config.macList|length > 0) and (config.isDenyList is sameas true) %}

#define WISUN_CONFIG_MAC_DENY_LIST_PRESENT
//! Wi-SUN MAC deny list
extern const wisun_config_mac_list_t wisun_config_mac_deny_list;
{%- endif -%}
{%- endif -%}
{% if config.devicePrivateKey is not none %}

#define WISUN_CONFIG_DEVICE_PRIVATE_KEY_PRESENT
//! Wi-SUN Device private key
extern const uint8_t wisun_config_device_private_key[];
{%- endif -%}
{% if config.deviceCertificate is not none %}

#define WISUN_CONFIG_DEVICE_CERTIFICATE_PRESENT
//! Wi-SUN Device certificate
extern const uint8_t wisun_config_device_certificate[];
{%- endif -%}
{% if config.caCertificate is not none %}

//! Wi-SUN CA certificate

#define WISUN_CONFIG_CA_CERTIFICATE_PRESENT
extern const uint8_t wisun_config_ca_certificate[];
{%- endif %}

#endif

#ifdef __cplusplus
}
#endif

#endif /* __SL_WISUN_CONFIG_H__ */